==> haskell-httpd-shed-0.4.1.1-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: httpd-shed
version: 0.4.1.1
id: httpd-shed-0.4.1.1-24qlWZDfnATEklZzDkHUdp
key: httpd-shed-0.4.1.1-24qlWZDfnATEklZzDkHUdp
license: BSD-3-Clause
copyright: (c) 2009 Andy Gill
maintainer: Ganesh Sittampalam
author: Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis: A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.
category: Network, Web
abi: c9063154d821af0c580db1f97cb3691b
exposed: True
exposed-modules:
    Network.Shed.Httpd
import-dirs: /usr/lib/ghc-8.6.5/site-local/httpd-shed-0.4.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/httpd-shed-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/httpd-shed-0.4.1.1
hs-libraries: HShttpd-shed-0.4.1.1-24qlWZDfnATEklZzDkHUdp
depends:
    base-4.12.0.0 network-2.8.0.0-LvSlvEKiGr81Yl4BCXERfa
    network-bsd-2.8.0.0-4EiLoRFpe6fGv9r56BEHsa
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
haddock-interfaces: /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html: /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-httpd-shed-0.4.1.1-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: httpd-shed
version: 0.4.1.1
id: httpd-shed-0.4.1.1-J4gvrq3agJzIvysBQMXSEk
key: httpd-shed-0.4.1.1-J4gvrq3agJzIvysBQMXSEk
license: BSD-3-Clause
copyright: (c) 2009 Andy Gill
maintainer: Ganesh Sittampalam
author: Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis: A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.
category: Network, Web
abi: f1d4d4e890e3a36de5ef0208a05e3b44
exposed: True
exposed-modules:
    Network.Shed.Httpd
import-dirs: /usr/lib/ghc-8.6.5/site-local/httpd-shed-0.4.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/httpd-shed-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/httpd-shed-0.4.1.1
hs-libraries: HShttpd-shed-0.4.1.1-J4gvrq3agJzIvysBQMXSEk
depends:
    base-4.12.0.0 network-2.8.0.1-L17Rv8Nouqq1qZnRto8DBo
    network-bsd-2.8.0.0-5JJyzkQLPeL5YlFilOngDf
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
haddock-interfaces: /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html: /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
